multidim
========

.. automodule:: multidim

   
   
   .. rubric:: Functions

   .. autosummary::
   
      lower_star_for_image
      stratum_from_distances
      stratum_maker
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      PointCloud
      Simplex
      SimplexStratum
      SimplicialComplex
   
   

   
   
   